@@ -4,7 +4,7 @@
 # ><>< ================================================================ ><>< #
 
 # ><>< # Transform Amino Acid to Codon Selection Coefficients (Reviewed)
-codonCoeffs <- function(s01x22, fixed=NULL){
+codonCoeffs <- function(s01x22){ # deleted "fixed=NULL"
     logicMat <- matrix(FALSE, 20, 61)
     codonSC <- rep(0, 61)
     count <- 0
@@ -13,9 +13,7 @@ codonCoeffs <- function(s01x22, fixed=NULL){
         logicMat[a0,newID] <- TRUE
     }
     
-    if(nsynVar(s01x22) > 1e-12){ aaID <- seq(1,20) }else{ aaID <- fixed }
-    
-    for(a1 in aaID){
+    for(a1 in seq(1,20)){
         count <- count + 1
         syns <- logicMat[a1,]
         if(sum(syns) == 1){
