@@ -5,8 +5,9 @@
 
 # ><>< # Generate Codon Frequencies
 codonFreq <- function(sc01x61){
-    sweights <- exp( coeffs(sc01x61) )
-    if(all( coeffs(sc01x61) > 1)) sweights <- log( coeffs(sc01x61) )
+    smax <- max( coeffs(sc01x61))
+    sShifted <- coeffs(sc01x61) - smax
+    sweights <- exp( sShifted )
     codonF <- sweights / sum(sweights)
     codonF <- new("codonvalues", cdnums=codonF)
     return(codonF)
